Python WireMock Admin API Client
================================

This is a python admin API client to a standalone WireMock server.

[![Build Status](https://travis-ci.org/platinummonkey/python-wiremock.svg?branch=master)](https://travis-ci.org/platinummonkey/python-wiremock)
[![Coverage Status](https://coveralls.io/repos/github/platinummonkey/python-wiremock/badge.svg?branch=master)](https://coveralls.io/github/platinummonkey/python-wiremock?branch=master)
[![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg)](http://wiremock.readthedocs.org/)


Install as Dependency
--------------------

To install:

    pip install wiremock


Documentation
-------------

wiremock documentation can be found at http://wiremock.readthedocs.org/


Pull Requests
-------------

General Rules:
  - All Tests must pass
  - Coverage shouldn't decrease
  - All Pull Requests should be rebased against master **before** submitting the PR.
